summaryrefslogtreecommitdiffstats
path: root/extra/kde321/selectdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'extra/kde321/selectdialog.h')
-rw-r--r--extra/kde321/selectdialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/extra/kde321/selectdialog.h b/extra/kde321/selectdialog.h
index b5e962c..804501b 100644
--- a/extra/kde321/selectdialog.h
+++ b/extra/kde321/selectdialog.h
@@ -43,7 +43,7 @@ class Resource;
*
* \code
*
* QPtrList<Resource> list = ... // can be retrived from KRES::Manager (e.g. KABC::AddressBook)
*
* KABC::Resource *res = KABC::SelectDialog::getResource( list, parentWdg );
* if ( !res ) {
@@ -62,7 +62,7 @@ class SelectDialog
* @param parent The parent widget
* @param name The name of the dialog
*/
- SelectDialog( QPtrList<Resource> list, QWidget *parent = 0,
+ SelectDialog( TQPtrList<Resource> list, TQWidget *parent = 0,
const char *name = 0);
/**
@@ -74,12 +74,12 @@ class SelectDialog
* Opens a dialog showing the available resources and returns the resource the
* user has selected. Returns 0, if the dialog was canceled.
*/
- static Resource *getResource( QPtrList<Resource> list, QWidget *parent = 0 );
+ static Resource *getResource( TQPtrList<Resource> list, TQWidget *parent = 0 );
private:
KListBox *mResourceId;
- QMap<int, Resource*> mResourceMap;
+ TQMap<int, Resource*> mResourceMap;
};
}
@@ -43,7 +43,7 @@ class Resource;
* \code
*
- * QPtrList<Resource> list = ... // can be retrived from KRES::Manager (e.g. KABC::AddressBook)
+ * TQPtrList<Resource> list = ... // can be retrived from KRES::Manager (e.g. KABC::AddressBook)
*
* KABC::Resource *res = KABC::SelectDialog::getResource( list, parentWdg );